==> skill-core-0.0.8-sources.jar: com/ptteng/sca/common/skill/client/UserClassRelationSCAClient.java <==
/**
 *
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.UserClassRelation;
import com.ptteng.common.skill.service.UserClassRelationService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class UserClassRelationSCAClient implements UserClassRelationService {

    private UserClassRelationService userClassRelationService;

    public UserClassRelationService getUserClassRelationService() {
        return userClassRelationService;
    }


    public void setUserClassRelationService(UserClassRelationService userClassRelationService) {
        this.userClassRelationService =userClassRelationService;
    }



    @Override
    public Long insert(UserClassRelation userClassRelation)throws ServiceException, ServiceDaoException{

        return userClassRelationService.insert(userClassRelation);


    }


    @Override
    public List<UserClassRelation> insertList(List<UserClassRelation> userClassRelationList)throws ServiceException, ServiceDaoException{

        return userClassRelationService.insertList(userClassRelationList);


    }


    @Override
    public boolean delete(Long id)throws ServiceException, ServiceDaoException{

        return userClassRelationService.delete(id);


    }


    @Override
    public boolean update(UserClassRelation userClassRelation)throws ServiceException, ServiceDaoException{

        return userClassRelationService.update(userClassRelation);


    }


    @Override
    public boolean updateList(List<UserClassRelation> userClassRelationList)throws ServiceException, ServiceDaoException{

        return userClassRelationService.updateList(userClassRelationList);


    }


    @Override
    public UserClassRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getObjectById(id);


    }



    @Override
    public List<UserClassRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getObjectsByIds(ids);


    }








    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public Long  getUserClassRelationIdByCidAndUid(Long cid,Long uid)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getUserClassRelationIdByCidAndUid(cid, uid);


    }

    @Override
    public Long getUserClassRelationIdByCidAndUidAndStatus(Long cid, Long uid, Integer status) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUserClassRelationIdByCidAndUidAndStatus(cid, uid, status);
    }

    @Override
    public List<Long> getUserClassRelationIdByOidAndUid(Long oid, Long uid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUserClassRelationIdByOidAndUid(oid, uid, start, limit);
    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public List<Long>  getUserClassRelationIdsByUid(Long uid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getUserClassRelationIdsByUid(uid, start, limit);


    }

    @Override
    public Long getUserClassRelationIdsByUidAndStatus(Long uid, Integer status) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUserClassRelationIdsByUidAndStatus(uid, status);
    }

    @Override
    public Integer countUserClassRelationIdsByUid(Long uid) throws ServiceException, ServiceDaoException {
        return userClassRelationService.countUserClassRelationIdsByUid(uid);
    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public List<Long>  getUserClassRelationIdsByCid(Long cid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getUserClassRelationIdsByCid(cid, start, limit);


    }



    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public Integer  countUserClassRelationIdsByCid(Long cid)throws ServiceException, ServiceDaoException{

        return userClassRelationService.countUserClassRelationIdsByCid(cid);


    }



    @Override
    public List<Long> getUserClassRelationIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.getUserClassRelationIds(start, limit);
    }

    @Override
    public Integer countUserClassRelationIds() throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.countUserClassRelationIds();
    }


    @Override
    public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
    }


    @Override
    public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.fakeDelete(clz, id);
    }



    @Override
    public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
        userClassRelationService.deleteList(clz, ids);

    }

    @Override
    public Map<Long,Map<Long,Long>> getUidNumRelationListByCids(List<Long> cids, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException{
        return userClassRelationService.getUidNumRelationListByCids(cids,start,limit);
    }

    @Override
    public Map<Long, Map<Long, String>> getUidSwearRelationListByCids(List<Long> cids, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUidSwearRelationListByCids(cids,start,limit);
    }


	@Override
	public List<Long> getUserIdsByCid(Long cid, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return this.userClassRelationService.getUserIdsByCid(cid, start, limit);
	}

}

==> skill-core-23.0.0-sources.jar: com/ptteng/sca/common/skill/client/UserClassRelationSCAClient.java <==
/**
 *
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.UserClassRelation;
import com.ptteng.common.skill.service.UserClassRelationService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class UserClassRelationSCAClient implements UserClassRelationService {

    private UserClassRelationService userClassRelationService;

    public UserClassRelationService getUserClassRelationService() {
        return userClassRelationService;
    }


    public void setUserClassRelationService(UserClassRelationService userClassRelationService) {
        this.userClassRelationService =userClassRelationService;
    }



    @Override
    public Long insert(UserClassRelation userClassRelation)throws ServiceException, ServiceDaoException{

        return userClassRelationService.insert(userClassRelation);


    }


    @Override
    public List<UserClassRelation> insertList(List<UserClassRelation> userClassRelationList)throws ServiceException, ServiceDaoException{

        return userClassRelationService.insertList(userClassRelationList);


    }


    @Override
    public boolean delete(Long id)throws ServiceException, ServiceDaoException{

        return userClassRelationService.delete(id);


    }


    @Override
    public boolean update(UserClassRelation userClassRelation)throws ServiceException, ServiceDaoException{

        return userClassRelationService.update(userClassRelation);


    }


    @Override
    public boolean updateList(List<UserClassRelation> userClassRelationList)throws ServiceException, ServiceDaoException{

        return userClassRelationService.updateList(userClassRelationList);


    }


    @Override
    public UserClassRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getObjectById(id);


    }



    @Override
    public List<UserClassRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getObjectsByIds(ids);


    }








    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public Long  getUserClassRelationIdByCidAndUid(Long cid,Long uid)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getUserClassRelationIdByCidAndUid(cid, uid);


    }

    @Override
    public Long getUserClassRelationIdByCidAndUidAndStatus(Long cid, Long uid, Integer status) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUserClassRelationIdByCidAndUidAndStatus(cid, uid, status);
    }

    @Override
    public List<Long> getUserClassRelationIdByOidAndUid(Long oid, Long uid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUserClassRelationIdByOidAndUid(oid, uid, start, limit);
    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public List<Long>  getUserClassRelationIdsByUid(Long uid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getUserClassRelationIdsByUid(uid, start, limit);


    }

    @Override
    public Long getUserClassRelationIdsByUidAndStatus(Long uid, Integer status) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUserClassRelationIdsByUidAndStatus(uid, status);
    }

    @Override
    public Integer countUserClassRelationIdsByUid(Long uid) throws ServiceException, ServiceDaoException {
        return userClassRelationService.countUserClassRelationIdsByUid(uid);
    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public List<Long>  getUserClassRelationIdsByCid(Long cid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{

        return userClassRelationService.getUserClassRelationIdsByCid(cid, start, limit);


    }



    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public Integer  countUserClassRelationIdsByCid(Long cid)throws ServiceException, ServiceDaoException{

        return userClassRelationService.countUserClassRelationIdsByCid(cid);


    }



    @Override
    public List<Long> getUserClassRelationIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.getUserClassRelationIds(start, limit);
    }

    @Override
    public Integer countUserClassRelationIds() throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.countUserClassRelationIds();
    }


    @Override
    public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
    }

    @Override
    public Object getObjectByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getObjectByDynamicCondition(aClass, map, integer, integer1);
    }


    @Override
    public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return userClassRelationService.fakeDelete(clz, id);
    }



    @Override
    public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
        userClassRelationService.deleteList(clz, ids);

    }

    @Override
    public Map<Long,Map<Long,Long>> getUidNumRelationListByCids(List<Long> cids, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException{
        return userClassRelationService.getUidNumRelationListByCids(cids,start,limit);
    }

    @Override
    public Map<Long, Map<Long, String>> getUidSwearRelationListByCids(List<Long> cids, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return userClassRelationService.getUidSwearRelationListByCids(cids,start,limit);
    }


	@Override
	public List<Long> getUserIdsByCid(Long cid, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return this.userClassRelationService.getUserIdsByCid(cid, start, limit);
	}

}
